;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "pyimpsort" "20250710.1607"
  "Sort Python imports."
  '((emacs  "24.3")
    (python "0"))
  :url "https://github.com/emacsorphanage/pyimpsort"
  :commit "70d739c134d89ba2025322fee101a13420d0b032"
  :revdesc "70d739c134d8"
  :keywords '("tools" "python" "convenience")
  :authors '(("Mario Rodas" . "marsam@users.noreply.github.com"))
  :maintainers '(("Alain Delplanque" . "alaindelplanque@mailoo.org")))
